
.. _api:

*************
API Reference
*************

The following list provides a detailed set of 
application programming interface (API) references
for developers, programmers and advanced users.

.. toctree::
    :maxdepth: 2
    :titlesonly:

    api_client